==> ofrak_io-1.0.0.tar.gz: ofrak_io-1.0.0/setup.py <==
import setuptools
from setuptools.command.egg_info import egg_info


class egg_info_ex(egg_info):
    """Includes license file into `.egg-info` folder."""

    def run(self):
        # don't duplicate license into `.egg-info` when building a distribution
        if not self.distribution.have_run.get("install", True):
            # `install` command is in progress, copy license
            self.mkpath(self.egg_info)
            self.copy_file("LICENSE", self.egg_info)

        egg_info.run(self)


with open("README.md") as f:
    long_description = f.read()


setuptools.setup(
    name="ofrak_io",
    version="1.0.0",
    description="Classes useful for general I/O in OFRAK",
    packages=setuptools.find_packages(),
    package_data={
        "ofrak_io": ["py.typed"],
    },
    install_requires=[
        "ofrak_type",
    ],
    extras_require={
        "test": [
            "ofrak",
            "black==22.3.0",
            "fun-coverage~=0.1.0",
            "hypothesis~=6.39.3",
            "mypy==0.942",
            "pytest",
            "pytest-asyncio>=0.19.0",
            "pytest-cov",
        ]
    },
    author="Red Balloon Security",
    author_email="ofrak@redballoonsecurity.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://ofrak.com/",
    download_url="https://github.com/redballoonsecurity/ofrak",
    project_urls={
        "Documentation": "https://ofrak.com/docs/",
        "Community License": "https://github.com/redballoonsecurity/ofrak/blob/master/LICENSE",
        "Commercial Licensing Information": "https://ofrak.com/license/",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: Other/Proprietary License",
        "License :: Free To Use But Restricted",
        "License :: Free For Home Use",
        "Topic :: Security",
        "Typing :: Typed",
    ],
    python_requires=">=3.7",
    license="Proprietary",
    license_files=["LICENSE"],
    cmdclass={"egg_info": egg_info_ex},
)

==> ofrak_io-1.1.0.tar.gz: ofrak_io-1.1.0/setup.py <==
import setuptools
from setuptools.command.egg_info import egg_info


class egg_info_ex(egg_info):
    """Includes license file into `.egg-info` folder."""

    def run(self):
        # don't duplicate license into `.egg-info` when building a distribution
        if not self.distribution.have_run.get("install", True):
            # `install` command is in progress, copy license
            self.mkpath(self.egg_info)
            self.copy_file("LICENSE", self.egg_info)

        egg_info.run(self)


with open("README.md") as f:
    long_description = f.read()


setuptools.setup(
    name="ofrak_io",
    version="1.1.0",
    description="Classes useful for general I/O in OFRAK",
    packages=setuptools.find_packages(),
    package_data={
        "ofrak_io": ["py.typed"],
    },
    install_requires=[
        "ofrak_type>=1.0",
    ],
    extras_require={
        "test": [
            "black==22.3.0",
            "fun-coverage==0.2.0",
            "hypothesis~=6.39.3",
            "mypy==0.942",
            "pytest",
            "pytest-asyncio==0.19.0",
            "pytest-cov",
        ]
    },
    author="Red Balloon Security",
    author_email="ofrak@redballoonsecurity.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://ofrak.com/",
    download_url="https://github.com/redballoonsecurity/ofrak",
    project_urls={
        "Documentation": "https://ofrak.com/docs/",
        "Community License": "https://github.com/redballoonsecurity/ofrak/blob/master/LICENSE",
        "Commercial Licensing Information": "https://ofrak.com/license/",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: Other/Proprietary License",
        "License :: Free To Use But Restricted",
        "License :: Free For Home Use",
        "Topic :: Security",
        "Typing :: Typed",
    ],
    python_requires=">=3.7",
    license="Proprietary",
    license_files=["LICENSE"],
    cmdclass={"egg_info": egg_info_ex},
)
